# Congruent Engineering Toolbox

This toolbox aims to provide convenient tools for early system and 
component design and operation optimization. It does so through combining a 
low-overhead implementation of basic SysML elements with a decentralised solver
logic.

This tool is not released on PyPI. Instead install it from git directly:

```bash
pip install git+https://github.com/CongruentEngineeringToolbox/cetpy.git
```